@@ -1,7 +1,8 @@
-use crate::{cli::CleanCommand, utils::helpers::default_output_directory};
+use crate::cli::CleanCommand;
 use anyhow::{anyhow, bail, Result};
+use forc_util::default_output_directory;
 use std::{path::PathBuf, process};
-use sway_utils::{find_manifest_dir, MANIFEST_FILE_NAME};
+use sway_utils::{find_cargo_manifest_dir, find_manifest_dir, MANIFEST_FILE_NAME};
 
 pub fn clean(command: CleanCommand) -> Result<()> {
     let CleanCommand { path } = command;
@@ -30,12 +31,14 @@ pub fn clean(command: CleanCommand) -> Result<()> {
 
     // Run `cargo clean`, forwarding stdout and stderr (`cargo clean` doesn't appear to output
     // anything as of writing this).
-    process::Command::new("cargo")
-        .arg("clean")
-        .stderr(process::Stdio::inherit())
-        .stdout(process::Stdio::inherit())
-        .output()
-        .map_err(|e| e)?;
+    if find_cargo_manifest_dir(&this_dir).is_some() {
+        process::Command::new("cargo")
+            .arg("clean")
+            .stderr(process::Stdio::inherit())
+            .stdout(process::Stdio::inherit())
+            .output()
+            .map_err(|e| e)?;
+    }
 
     Ok(())
 }
