@@ -11,21 +11,19 @@ license = "Apache-2.0"
 name = "{project_name}"
 
 [dependencies]
-core = {{ git = "http://github.com/FuelLabs/sway-lib-core" }}
-std = {{ git = "http://github.com/FuelLabs/sway-lib-std" }}
+std = {{ git = "https://github.com/FuelLabs/sway-lib-std" }}
 "#
     )
 }
 
 /// Creates a default Cargo manifest for the Rust-based tests.
 /// It includes necessary packages to make the Rust-based
-/// tests work, such as the abigen macro, fuels-rs, and
-/// the fuel client.
+/// tests work.
 pub(crate) fn default_tests_manifest(project_name: &str) -> String {
     let real_name = whoami::realname();
 
     format!(
-        r#"[package]
+        r#"[project]
 authors = ["{real_name}"]
 edition = "2021"
 license = "Apache-2.0"
@@ -33,11 +31,11 @@ name = "{project_name}"
 version = "0.1.0"
 
 [dependencies]
-fuel-gql-client = {{ version = "0.2", default-features = false }}
-fuel-tx = "0.3"
-fuels-abigen-macro = "0.3"
-fuels-contract = "0.3"
-fuels-core = "0.3"
+fuel-gql-client = {{ version = "0.4", default-features = false }}
+fuel-tx = "0.6"
+fuels-abigen-macro = "0.6"
+fuels-contract = "0.6"
+fuels-core = "0.6"
 rand = "0.8"
 tokio = {{ version = "1.12", features = ["rt", "macros"] }}
 
@@ -76,3 +74,19 @@ target
 "#
     .into()
 }
+
+#[test]
+fn parse_default_manifest() {
+    println!(
+        "{:#?}",
+        toml::from_str::<forc_pkg::Manifest>(&default_manifest("test_proj")).unwrap()
+    )
+}
+
+#[test]
+fn parse_default_tests_manifest() {
+    println!(
+        "{:#?}",
+        toml::from_str::<forc_pkg::Manifest>(&default_tests_manifest("test_proj")).unwrap()
+    )
+}
